import 'package:fluro/fluro.dart';
import 'package:flutter/material.dart';
import 'package:memri/configs/routes/route_handler.dart';
import 'package:memri/core/services/analytics_service.dart';

class Routes {
  static String home = '/';
  static String workspace = '/workspace';
  static String oauth = '/oauth';
  static String error = '/error';

  static String onboarding = '/account';
  static String login = '/account/login';
  static String loginDev = '/account/login_dev';
  static String saveKeys = '/account/save_keys';

  static String data = '/workspace/data';
  static String importerConnect = '/workspace/data/importer';
  static String importerCreate = '/workspace/data/importer/create';
  static String importerDownloading = '/workspace/data/importer/downloading';
  static String importerError = '/workspace/data/importer/error';

  static String projects = '/workspace/projects';
  static String projectsCreate = '/workspace/projects/create';
  static String projectsSummary = '/workspace/projects/summary';
  static String projectsLabelData = '/workspace/projects/create/label_data';
  static String projectsAppCreate = '/workspace/projects/create/app';
  static String projectsAppPreview = '/workspace/projects/create/app/preview';
  static String cvu = '/workspace/cvu';

  static String keys = '/workspace/keys';

  static String apps = '/workspace/apps';
  static String appConfigure = '/workspace/apps/configure';
  static String inbox = '/workspace/apps/inbox';
  static String feed = '/workspace/apps/feed';

  static void configureRoutes(FluroRouter router) {
    router.notFoundHandler = notFoundHandler;
    router.define(home, handler: workspaceScreenHandler);
    router.define(workspace, handler: workspaceScreenHandler);
    router.define(onboarding, handler: onboardingScreenHandler);
    router.define(login, handler: loginScreenHandler);
    router.define(loginDev, handler: loginDeveloperScreenHandler);
    router.define(saveKeys, handler: saveKeysScreenHandler);
    router.define(error, handler: errorScreenHandler);
    router.define(keys, handler: keysScreenHandler);

    router.define(data, handler: dataScreenHandler);
    router.define(oauth, handler: oauthScreenHandler);
    router.define(importerCreate, handler: importerCreateScreenHandler);
    router.define(importerConnect, handler: importerConnectScreenHandler);
    router.define(importerDownloading,
        handler: importerDownloadingScreenHandler);
    router.define(importerError, handler: importerErrorScreenHandler);

    router.define(apps, handler: appsScreenHandler);
    router.define(appConfigure, handler: appsConfigureScreenHandler);
    router.define(inbox, handler: appsInboxScreenHandler);
    router.define(feed, handler: appsFeedScreenHandler);

    router.define(projects, handler: projectsScreenHandler);
    router.define(projectsCreate, handler: projectsCreateScreenHandler);
    router.define(projectsLabelData, handler: projectsLabelDataScreenHandler);
    router.define(projectsSummary, handler: projectsSummaryScreenHandler);
    router.define(projectsAppCreate, handler: projectsAppCreateScreenHandler);
    router.define(projectsAppPreview, handler: projectsAppPreviewScreenHandler);

    router.define(cvu, handler: cvuHandler);
  }
}

class RouteNavigator {
  static late FluroRouter router;

  static Future<dynamic> navigateTo({
    required String route,
    required BuildContext context,
    Duration transitionDuration = const Duration(milliseconds: 300),
    TransitionType transition = TransitionType.fadeIn,
    Map<String, dynamic>? param,
    bool replace = false,
    bool clearStack = false,
    RouteTransitionsBuilder? transitionBuilder,
  }) {
    String routePath = route;
    if (param != null) {
      bool isFirst = true;
      param.forEach((key, value) {
        routePath += '${isFirst ? '?' : '&'}$key=$value';
        isFirst = false;
      });
    }
    AnalyticsService().logRouteNavigation(routePath);
    return router.navigateTo(
      context,
      routePath,
      replace: replace,
      transition: transition,
      clearStack: clearStack,
      transitionDuration: transitionDuration,
      transitionBuilder: transitionBuilder,
    );
  }

  static void navigateBack<T>(BuildContext context, [T? result]) {
    AnalyticsService().logRouteNavigation('back');
    router.pop(context, result);
  }
}
