import 'package:flutter/material.dart';
import 'package:memri/utilities/helpers/app_helper.dart';

class AppStyles {
  String name = 'Karla';
  double size;
  FontWeight? weight;
  bool italic;
  double? letterSpacing;

  AppStyles(
      {String? name,
      double? size,
      this.weight = FontWeight.normal,
      this.italic = false,
      this.letterSpacing})
      : name = name ?? 'Karla',
        size = size ?? 15;

  Map<String, dynamic> get font {
    return {
      'family': name,
      'size': size,
      'weight': weight ?? FontWeight.normal,
      'italic': italic
    };
  }

  static const Map<String, FontWeight> weights = {
    'black': FontWeight.w900,
    'bold': FontWeight.w700,
    'heavy': FontWeight.w800,
    'light': FontWeight.w300,
    'medium': FontWeight.w500,
    'regular': FontWeight.normal,
    'semibold': FontWeight.w600,
    'thin': FontWeight.w200,
    'ultraLight': FontWeight.w100,
  };

  static Map<String, AppStyles> predefined = {
    'headline1': AppStyles(
        size: headline1.fontSize!,
        weight: headline1.fontWeight,
        letterSpacing: headline1.letterSpacing),
    'headline2': AppStyles(
        size: headline2.fontSize!,
        weight: headline2.fontWeight,
        letterSpacing: headline2.letterSpacing),
    'headline3': AppStyles(
        size: headline3.fontSize!,
        weight: headline3.fontWeight,
        letterSpacing: headline3.letterSpacing),
    'headline4': AppStyles(
        size: headline4.fontSize!,
        weight: headline4.fontWeight,
        letterSpacing: headline4.letterSpacing),
    'bodyText1': AppStyles(
        size: bodyText1.fontSize!,
        weight: bodyText1.fontWeight,
        letterSpacing: bodyText1.letterSpacing),
    'body_bold': AppStyles(
        size: bodyBold.fontSize!,
        weight: bodyBold.fontWeight,
        letterSpacing: bodyBold.letterSpacing),
    'bodyText2': AppStyles(
        size: bodyText2.fontSize!,
        weight: bodyText2.fontWeight,
        letterSpacing: bodyText2.letterSpacing),
    'button_label': AppStyles(
        size: buttonLabel.fontSize!,
        weight: buttonLabel.fontWeight,
        letterSpacing: buttonLabel.letterSpacing),
    'tile_Label': AppStyles(
        size: tileLabel.fontSize!,
        weight: tileLabel.fontWeight,
        letterSpacing: tileLabel.letterSpacing),
    'link': AppStyles(
        size: link.fontSize!,
        weight: link.fontWeight,
        letterSpacing: link.letterSpacing),
    'small_caps': AppStyles(
        size: smallCaps.fontSize!,
        weight: smallCaps.fontWeight,
        letterSpacing: smallCaps.letterSpacing),
    'small_caps_bold': AppStyles(
        size: smallCaps.fontSize!,
        weight: FontWeight.w700,
        letterSpacing: smallCaps.letterSpacing),
    'tab_list': AppStyles(
      size: tabList.fontSize!,
      weight: tabList.fontWeight,
    ),
    'body_tiny': AppStyles(
      size: bodyTiny.fontSize!,
      weight: bodyTiny.fontWeight,
    ),
    'body_tiny_bold': AppStyles(
      size: bodyTiny.fontSize!,
      weight: FontWeight.w700,
    ),
    'ul': AppStyles(
      size: ul.fontSize!,
      weight: ul.fontWeight,
    ),
    'input': AppStyles(
      size: 13,
      weight: FontWeight.w400,
    ),
  };

  static const headline1 = TextStyle(
      fontFamily: 'Karla',
      fontSize: 30,
      fontWeight: FontWeight.w400,
      letterSpacing: -0.01,
      color: Color(0xff333333));
  static const headline2 = TextStyle(
      fontFamily: 'Karla',
      fontSize: 20,
      fontWeight: FontWeight.w400,
      letterSpacing: -0.01,
      color: Color(0xff333333));
  static const headline3 = TextStyle(
      fontFamily: 'Karla',
      fontSize: 20,
      fontWeight: FontWeight.w400,
      color: Color(0xff333333));
  static const headline4 = TextStyle(
      fontFamily: 'Karla',
      fontSize: 16,
      fontWeight: FontWeight.w300,
      letterSpacing: 0.16,
      color: Color(0xff333333));
  static const bodyText1 = TextStyle(
      fontFamily: 'Karla',
      fontSize: 14,
      fontWeight: FontWeight.w400,
      color: Color(0xff333333));
  static const bodyBold = TextStyle(
      fontFamily: 'Karla',
      fontSize: 14,
      fontWeight: FontWeight.w700,
      color: Color(0xff333333));
  static const bodyText2 = TextStyle(
      fontFamily: 'Karla',
      fontSize: 12,
      fontWeight: FontWeight.w400,
      color: Color(0xff333333));
  static const buttonLabel = TextStyle(
      fontFamily: 'Karla',
      fontSize: 14,
      fontWeight: FontWeight.w400,
      color: Colors.white);
  static const tileLabel = TextStyle(
      fontFamily: 'Karla',
      fontSize: 13,
      fontWeight: FontWeight.w400,
      letterSpacing: 1.04,
      color: Color(0xff333333));
  static const link = TextStyle(
      fontFamily: 'Karla',
      fontSize: 14,
      fontWeight: FontWeight.w400,
      color: Color(0xff333333));
  static const smallCaps = TextStyle(
      fontFamily: 'Karla',
      fontSize: 10,
      fontWeight: FontWeight.w700,
      letterSpacing: 1.76,
      color: Color(0xff333333));

  static const code = TextStyle(
      fontFamily: 'IBMPlexMono',
      fontSize: 11,
      fontWeight: FontWeight.w400,
      color: Color(0xff333333));

  static const tabList = TextStyle(
      fontFamily: 'Karla',
      fontSize: 14,
      fontWeight: FontWeight.w400,
      color: Color(0xff333333));
  static const bodyTiny = TextStyle(
      fontFamily: 'Karla',
      fontSize: 12,
      fontWeight: FontWeight.w400,
      color: Color(0xff333333));
  static const ul = TextStyle(
      fontFamily: 'Karla',
      fontSize: 14,
      fontWeight: FontWeight.w400,
      color: Color(0xff333333));
  static const input = TextStyle(
      fontFamily: 'Karla',
      fontSize: 13,
      fontWeight: FontWeight.w400,
      color: Color(0xff989898));
  static const nameStyle =
      TextStyle(fontFamily: 'Karla', fontSize: 13, fontWeight: FontWeight.w400);
}

final ButtonStyle primaryButtonStyle = TextButton.styleFrom(
    backgroundColor: app.colors.brandOrange,
    primary: app.colors.brandWhite,
    textStyle: AppStyles.buttonLabel,
    minimumSize: Size.zero,
    tapTargetSize: MaterialTapTargetSize.shrinkWrap,
    padding: const EdgeInsets.symmetric(horizontal: 10),
    onSurface: Colors.white);

final ButtonStyle secondaryButtonStyle = TextButton.styleFrom(
    primary: app.colors.brandOrange,
    textStyle: AppStyles.buttonLabel,
    minimumSize: Size.zero,
    tapTargetSize: MaterialTapTargetSize.shrinkWrap,
    padding: const EdgeInsets.symmetric(horizontal: 10),
    onSurface: Colors.white);

final ButtonStyle tertiaryButtonStyle = TextButton.styleFrom(
    backgroundColor: app.colors.brandBlack,
    primary: app.colors.brandWhite,
    textStyle: AppStyles.buttonLabel,
    minimumSize: Size.zero,
    tapTargetSize: MaterialTapTargetSize.shrinkWrap,
    padding: const EdgeInsets.all(10),
    onSurface: Colors.white);

final ButtonStyle quartenaryButtonStyle = TextButton.styleFrom(
    primary: app.colors.brandGreen,
    textStyle: AppStyles.buttonLabel,
    minimumSize: Size.zero,
    tapTargetSize: MaterialTapTargetSize.shrinkWrap,
    padding: const EdgeInsets.all(10),
    onSurface: Colors.white);

final Map<String, ButtonStyle> buttonStyles = {
  'primaryButton': primaryButtonStyle,
  'secondaryButton': secondaryButtonStyle,
  'tertiaryButton': tertiaryButtonStyle
};
