import 'package:flutter/material.dart';
import 'package:memri/core/models/item.dart';
import 'package:memri/core/cvu/constants/cvu_color.dart';
import 'package:memri/core/cvu/widgets/renderers/renderer.dart';

class SingleItemRendererView extends Renderer {
  const SingleItemRendererView({Key? key, required viewContext})
      : super(key: key, viewContext: viewContext);

  @override
  SingleItemRendererViewState createState() => SingleItemRendererViewState();
}

class SingleItemRendererViewState extends RendererViewState {
  EdgeInsets? insets;
  Color? backgroundColor;

  @override
  initState() {
    super.initState();
    init();
  }

  @override
  void didUpdateWidget(covariant Renderer oldWidget) {
    super.didUpdateWidget(oldWidget);
    setState(() => init());
  }

  @override
  dispose() {
    super.dispose();
  }

  updateState() {
    setState(() {});
  }

  @override
  void init() {
    insets = viewContext.rendererDefinitionPropertyResolver.edgeInsets ??
        EdgeInsets.fromLTRB(30, 0, 30, 0);
    backgroundColor =
        viewContext.rendererDefinitionPropertyResolver.backgroundColor ??
            CVUColor.system('systemBackground');
    scrollable =
        viewContext.rendererDefinitionPropertyResolver.boolean('scrollable') ??
            false;
  }

  @override
  Widget build(BuildContext context) {
    return ValueListenableBuilder(
        valueListenable: viewContext.itemsValueNotifier,
        builder: (BuildContext context, List<Item> value, Widget? child) {
          var item = viewContext.focusedItem ?? viewContext.items.asMap()[0];
          Widget group;
          if (item != null) {
            group = viewContext.render(item: item, items: viewContext.items);
          } else {
            group = emptyResult ?? Center(child: Text('No item selected'));
          }
          if (insets != null) {
            group = Padding(
              padding: insets!,
              child: group,
            );
          }
          if (backgroundColor != null) {
            group = ColoredBox(
              color: backgroundColor!,
              child: group,
            );
          }
          if (scrollable) {
            return CustomScrollView(
              slivers: [
                SliverFillRemaining(
                  hasScrollBody: false,
                  fillOverscroll: false,
                  child: group,
                ),
              ],
            );
          }
          return group;
        });
  }
}
