//  Created by T Brennan on 23/1/21.

import 'package:flutter/cupertino.dart';
import 'package:memri/core/cvu/controllers/view_context_controller.dart';
import 'package:memri/core/cvu/widgets/renderers/chart_renderer.dart';
import 'package:memri/core/cvu/widgets/renderers/custom_renderer.dart';
import 'package:memri/core/cvu/widgets/renderers/grid_renderer.dart';
import 'package:memri/core/cvu/widgets/renderers/list_renderer.dart';
import 'package:memri/core/cvu/widgets/renderers/photo_viewer_renderer.dart';
import 'package:memri/core/cvu/widgets/renderers/single_item_renderer.dart';

class SceneContentView extends StatefulWidget {
  final ViewContextController viewContext;

  const SceneContentView({required this.viewContext, Key? key})
      : super(key: key);

  @override
  SceneContentViewState createState() => SceneContentViewState();
}

class SceneContentViewState extends State<SceneContentView> {
  @override
  initState() {
    super.initState();
    widget.viewContext.onAppear();
    widget.viewContext.addListener(updateState);
  }

  @override
  dispose() {
    super.dispose();
    widget.viewContext.onDisappear();
    widget.viewContext.removeListener(updateState);
  }

  updateState() {
    setState(() {});
  }

  /// Translates the rendererName to the correct Renderer view
  Widget get renderer {
    switch (widget.viewContext.config.rendererName.toLowerCase()) {
      case 'list':
        return ListRendererView(viewContext: widget.viewContext);
      case 'grid':
        return GridRendererView(viewContext: widget.viewContext);
      case 'photoviewer':
        return PhotoViewerRendererView(viewContext: widget.viewContext);
      case 'chart':
        return ChartRendererView(viewContext: widget.viewContext);
      case 'singleitem':
        return SingleItemRendererView(viewContext: widget.viewContext);
      case 'custom':
        return CustomRendererView(viewContext: widget.viewContext);
      default:
        return Text('No renderer selected',
            style: TextStyle(fontWeight: FontWeight.bold));
    }
  }

  //TODO onAppear, onDisappear

  @override
  Widget build(BuildContext context) {
    return renderer;
  }
}
