import 'package:memri/core/apis/pod_api.dart';
import 'package:memri/core/models/pod/pod_config.dart';
import 'package:memri/core/services/api_service.dart';
import 'package:memri/utilities/helpers/app_helper.dart';
import 'package:shared_preferences/shared_preferences.dart';

class OAuthService extends ApiService<PodAPI> {
  OAuthService(this._prefs) : super(api: PodAPI()) {
    _setConfig();
  }

  final SharedPreferences _prefs;
  late PodConfig podConfig;

  void _setConfig() {
    podConfig = PodConfig(
      baseUrl:
          _prefs.getString(app.keys.podAddress) ?? app.settings.defaultPodUrl,
      ownerKey: _prefs.getString(app.keys.ownerKey) ?? '',
      databaseKey: _prefs.getString(app.keys.dbKey) ?? '',
      apiVersion: app.settings.podVersion,
    );
    api.setConnectionConfig(podConfig);
  }

  Future<Map<String, dynamic>> oauthAccessToken(
      String oauthVerifier, String oauthToken, String oauthTokenSecret) async {
    _setConfig();
    return await api.oauthAccessToken(
        oauthVerifier, oauthToken, oauthTokenSecret);
  }

  Future<Map<String, dynamic>> oauthRequestToken(
      String service, String callback_url) async {
    _setConfig();
    return await api.oauthRequestToken(service, callback_url);
  }

  Future<dynamic> getQrCodeSvg(String webserverUrl) async {
    _setConfig();
    return await api.getQrCodeSvg(webserverUrl);
  }
}
