import 'package:dio/dio.dart';
import 'package:get_it/get_it.dart';
import 'package:memri/core/cvu/controllers/cvu_controller.dart';
import 'package:memri/core/services/analytics_service.dart';
import 'package:memri/core/services/database/schema.dart';
import 'package:memri/core/services/gitlab_service.dart';
import 'package:memri/core/services/graph_service.dart';
import 'package:memri/core/services/log_service.dart';
import 'package:memri/core/services/network_service.dart';
import 'package:memri/core/services/oauth_service.dart';
import 'package:memri/core/services/pod_service.dart';
import 'package:memri/core/services/search_service.dart';
import 'package:memri/core/services/storage_service.dart';
import 'package:memri/providers/app_provider.dart';
import 'package:memri/providers/data_app_provider.dart';
import 'package:memri/providers/importer_provider.dart';
import 'package:memri/providers/navigation_provider.dart';
import 'package:memri/providers/oauth_provider.dart';
import 'package:memri/providers/pod_provider.dart';
import 'package:memri/providers/project_provider.dart';
import 'package:shared_preferences/shared_preferences.dart';

final locator = GetIt.instance;

Future<void> setup() async {
  SharedPreferences prefs = await SharedPreferences.getInstance();

  /// PROVIDERS
  locator.registerLazySingleton<AppProvider>(
      () => AppProvider(locator(), locator()));
  locator.registerLazySingleton<PodProvider>(() => PodProvider(
        locator(),
        locator(),
        locator(),
        locator(),
        locator(),
        locator(),
        locator(),
        locator(),
      ));
  locator.registerLazySingleton<NavigationProvider>(
      () => NavigationProvider(locator(), locator()));
  locator.registerLazySingleton<OAuthProvider>(() => OAuthProvider(
        locator(),
        locator(),
        locator(),
        locator(),
        locator(),
      ));
  locator.registerLazySingleton<ImporterProvider>(
      () => ImporterProvider(locator(), locator(), locator(), locator()));
  locator.registerLazySingleton<ProjectProvider>(
      () => ProjectProvider(locator(), locator(), locator()));
  locator.registerLazySingleton<DataAppProvider>(
      () => DataAppProvider(locator(), locator(), locator()));

  /// CVU
  locator.registerLazySingleton<CVUController>(() => CVUController(locator()));
  locator.registerLazySingleton<Schema>(() => Schema(locator()));

  /// SERVICES
  locator.registerLazySingleton<PodService>(() => PodService(locator()));
  locator.registerLazySingleton<GitlabService>(() => GitlabService(locator()));
  locator.registerLazySingleton<GraphService>(() => GraphService(locator()));
  locator.registerLazySingleton<OAuthService>(() => OAuthService(locator()));
  locator.registerLazySingleton<LogService>(() => LogService());
  locator.registerLazySingleton<SearchService>(() => SearchService());
  locator.registerLazySingleton<StorageService>(() => StorageService());
  locator.registerLazySingleton<NetworkService>(() => NetworkService());
  locator.registerLazySingleton<AnalyticsService>(() => AnalyticsService());

  /// CLIENTS
  locator.registerSingleton<Dio>(Dio());

  /// PLUGINS
  locator.registerLazySingleton<SharedPreferences>(() => prefs);
}
