import 'package:flutter/material.dart';
import 'package:memri/configs/routes/route_navigator.dart';
import 'package:memri/core/services/analytics_service.dart';
import 'package:memri/core/services/network_service.dart';
import 'package:memri/utilities/helpers/app_helper.dart';

enum MenuState { close, open }

class NavigationProvider with ChangeNotifier {
  final NetworkService _networkService;
  final AnalyticsService _analyticsService;

  NavigationProvider(this._networkService, this._analyticsService);

  MenuState _menuState = MenuState.close;
  int selectedTabIndex = 0;

  bool get isMenuVisible => _menuState == MenuState.open;

  void openMenu() {
    _menuState = MenuState.open;
    notifyListeners();
  }

  void closeMenu() {
    _menuState = MenuState.close;
    notifyListeners();
  }

  void openPodKeys(BuildContext context) {
    closeMenu();
    RouteNavigator.navigateTo(context: context, route: Routes.keys);
  }

  void openGuideLink() {
    _networkService.openLink(app.settings.guideUrl);
    _analyticsService.logNavigationButton(AnalyticsEvents.guide);
  }

  void openDiscordLink() {
    _networkService.openLink(app.settings.discordUrl);
    _analyticsService.logNavigationButton(AnalyticsEvents.discord);
  }

  void openDocumentationLink() {
    _networkService.openLink(app.settings.documentationUrl);
    _analyticsService.logNavigationButton(AnalyticsEvents.documentation);
  }

  void openGitlabLink() {
    _networkService.openLink(app.settings.gitlabUrl);
    _analyticsService.logNavigationButton(AnalyticsEvents.gitlab);
  }

  void openPrivacyLink() {
    _networkService.openLink(app.settings.privacyUrl);
    _analyticsService.logNavigationButton(AnalyticsEvents.privacy);
  }

  void openContactLink() {
    _networkService.openLink(app.settings.contactUrl);
    _analyticsService.logNavigationButton(AnalyticsEvents.contact);
  }

  void openDataExplorerLink() {
    _networkService.openLink(app.settings.dataExplorerUrl);
    _analyticsService.logNavigationButton(AnalyticsEvents.dataExplorer);
  }

  void openPluginDocLink() {
    _networkService.openLink(app.settings.pluginDocUrl);
    _analyticsService.logNavigationButton(AnalyticsEvents.pluginDoc);
  }

  void openDiscordPluginLink() {
    _networkService.openLink(app.settings.discordPluginUrl);
    _analyticsService.logNavigationButton(AnalyticsEvents.discordPlugin);
  }

  void setSelectedTabIndex(int index) {
    selectedTabIndex = index;

    /// TODO: FIX THIS, CAUSE EXCEPTION
    notifyListeners();
  }
}
