import 'package:flutter/material.dart';
import 'package:memri/constants/app_styles.dart';
import 'package:memri/core/controllers/app_controller.dart';
import 'package:memri/utilities/helpers/app_helper.dart';
import 'package:memri/widgets/empty.dart';
import 'package:memri/widgets/scaffold/account_scaffold.dart';

class ErrorScreen extends StatefulWidget {
  const ErrorScreen({Key? key}) : super(key: key);

  @override
  State<ErrorScreen> createState() => _ErrorScreenState();
}

class _ErrorScreenState extends State<ErrorScreen> {
  AppController appController = AppController.shared;

  @override
  Widget build(BuildContext context) {
    return AccountScaffold(showSlider: false, child: showCurrentError());
  }

  Widget showCurrentError() {
    switch (appController.state.value) {
      case AppState.incompatibleDevice:
        return OnboardingIncompatibleDeviceError();
      case AppState.incompatibleBrowser:
        return OnboardingIncompatibleBrowserError();
      case AppState.maintenance:
        return OnboardingMaintenance();
      default:
        return Empty();
    }
  }
}

class OnboardingIncompatibleDeviceError extends StatelessWidget {
  const OnboardingIncompatibleDeviceError({Key? key}) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return Column(
      crossAxisAlignment: CrossAxisAlignment.start,
      children: [
        SizedBox(height: 113),
        Text(
          'Device not supported.',
          style: AppStyles.headline1.copyWith(color: app.colors.brandOrange),
        ),
        SizedBox(height: 40),
        Text(
          'We are sorry but your device is not supported yet. Please try again on your computer.',
          style: AppStyles.bodyText1,
        ),
      ],
    );
  }
}

class OnboardingIncompatibleBrowserError extends StatelessWidget {
  const OnboardingIncompatibleBrowserError({Key? key}) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return Column(
      crossAxisAlignment: CrossAxisAlignment.start,
      children: [
        SizedBox(
          height: 113,
        ),
        Text(
          'Browser not supported.',
          style: AppStyles.headline1.copyWith(color: app.colors.brandOrange),
        ),
        SizedBox(
          height: 40,
        ),
        Text(
          'We are sorry but your browser is not supported yet. List of supported browsers: ',
          style: AppStyles.bodyText1,
        ),
        Padding(
          padding: const EdgeInsets.fromLTRB(20, 10, 0, 0),
          child: RichText(
              text: TextSpan(style: AppStyles.headline4, children: const [
            TextSpan(text: '• Chrome\n'),
            TextSpan(text: '• Firefox (in non private mode)\n'),
            TextSpan(text: '• Edge\n'),
            TextSpan(text: '• Brave')
          ])),
        )
      ],
    );
  }
}

class OnboardingMaintenance extends StatelessWidget {
  const OnboardingMaintenance({Key? key}) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return Column(
      crossAxisAlignment: CrossAxisAlignment.start,
      children: const [
        SizedBox(
          height: 113,
        ),
        Text(
          'We need a moment!',
          style: AppStyles.headline1,
        ),
        SizedBox(
          height: 40,
        ),
        Text(
          'We’re updating the app. It should be ready to use again shortly.',
          style: AppStyles.bodyText1,
        ),
        SizedBox(
          height: 20,
        ),
        Text(
          'Please try again later.',
          style: AppStyles.bodyText1,
        )
      ],
    );
  }
}
