import 'package:flutter/material.dart';
import 'package:memri/core/models/item.dart';
import 'package:memri/core/models/running_plugin.dart';
import 'package:memri/providers/data_app_provider.dart';
import 'package:memri/providers/navigation_provider.dart';
import 'package:memri/utilities/helpers/app_helper.dart';
import 'package:memri/widgets/data_app/data_app.dart';
import 'package:memri/widgets/data_app/data_app_logs.dart';
import 'package:memri/widgets/data_app/data_app_settings.dart';
import 'package:memri/widgets/loading_indicator.dart';
import 'package:memri/widgets/navigation/top_bar.dart';
import 'package:memri/widgets/scaffold/workspace_scaffold.dart';
import 'package:provider/provider.dart';

class AppsConfigureScreen extends StatefulWidget {
  const AppsConfigureScreen(
      {Key? key, required this.tab, required this.pluginId})
      : super(key: key);

  final String tab;
  final String pluginId;

  @override
  State<AppsConfigureScreen> createState() => _AppsConfigureScreenState();
}

class _AppsConfigureScreenState extends State<AppsConfigureScreen> {
  RunningPlugin? runningPlugin;

  late final _dataAppProvider =
      Provider.of<DataAppProvider>(context, listen: false);
  late final _navProvider =
      Provider.of<NavigationProvider>(context, listen: false);
  late List<TabItem> tabs = [
    TabItem(
        name: runningPlugin?.plugin.get('name') ?? 'Data App',
        onTap: () => _dataAppProvider.setDataAppState(AppState.showApp)),
    TabItem(
        name: 'Settings',
        onTap: () => _dataAppProvider.setDataAppState(AppState.showSettings)),
    TabItem(
        name: 'Logs',
        onTap: () => _dataAppProvider.setDataAppState(AppState.showLogs)),
  ];

  @override
  initState() {
    if (widget.tab == AppState.showSettings.toUrlString()) {
      _dataAppProvider.currentAppState = AppState.showSettings;
      _navProvider.setSelectedTabIndex(1);
    } else if (widget.tab == AppState.showLogs.toUrlString()) {
      _dataAppProvider.currentAppState = AppState.showLogs;
      _navProvider.setSelectedTabIndex(2);
    } else {
      _dataAppProvider.currentAppState = AppState.showApp;
      _navProvider.setSelectedTabIndex(0);
    }

    _setup();
    super.initState();
  }

  Future<void> _setup() async {
    _dataAppProvider.currentPlugin =
        (await _dataAppProvider.getPlugin(widget.pluginId))!;
    List<Item> runs =
        await _dataAppProvider.getPluginRunsForPlugin(widget.pluginId);

    if (runs.isEmpty) {
      _dataAppProvider.runDataAppPlugin(_dataAppProvider.currentPlugin!);
    } else {
      _dataAppProvider.currentPluginRun = runs[0];
      _dataAppProvider.setDataAppState(AppState.showApp);
    }
  }

  @override
  Widget build(BuildContext context) {
    return WorkspaceScaffold(
      currentItem: NavigationItem.apps,
      backgroundColor: app.colors.white,
      tabs: tabs,
      child: Consumer<DataAppProvider>(
        builder: (context, dataAppProvider, _) {
          switch (dataAppProvider.currentAppState) {
            case AppState.deploying:
              return LoadingIndicator();
            case AppState.initialPredictions:
              return LoadingIndicator();
            case AppState.showApp:
              return DataApp(
                runningPlugin: runningPlugin,
                pluginId: widget.pluginId,
              );
            case AppState.showLogs:
              return DataAppLogs(currentRunLog: dataAppProvider.currentRunLog);
            case AppState.showSettings:
              return DataAppSettings(runningPlugin: runningPlugin);
          }
        },
      ),
    );
  }
}
