import 'package:flutter/material.dart';
import 'package:memri/constants/app_styles.dart';
import 'package:memri/core/models/item.dart';
import 'package:memri/providers/data_app_provider.dart';
import 'package:memri/utilities/helpers/app_helper.dart';
import 'package:memri/utilities/helpers/responsive_helper.dart';
import 'package:memri/widgets/scaffold/workspace_scaffold.dart';
import 'package:provider/provider.dart';

class AppsFeedScreen extends StatefulWidget {
  const AppsFeedScreen({Key? key, this.showMainNavigation = true})
      : super(key: key);

  final bool showMainNavigation;

  @override
  _AppsFeedScreenState createState() => _AppsFeedScreenState();
}

class _AppsFeedScreenState extends State<AppsFeedScreen> {
  late final _dataAppProvider =
      Provider.of<DataAppProvider>(context, listen: false);
  int selectedFeedItem = 0;
  Item? activeFeedItem;

  @override
  void initState() {
    _dataAppProvider.getFeed();
    super.initState();
  }

  @override
  void dispose() {
    _dataAppProvider.feedStreamSubscription?.cancel();
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    return WorkspaceScaffold(
      currentItem: NavigationItem.apps,
      child: Consumer<DataAppProvider>(
        builder: (context, provider, _) {
          return Container(
            width: MediaQuery.of(context).size.width,
            padding: EdgeInsets.fromLTRB(30, 30, 0, 0),
            child: Row(
              crossAxisAlignment: CrossAxisAlignment.start,
              children: [
                Expanded(
                  child: Container(
                    decoration: BoxDecoration(
                        border: Border(
                            right: BorderSide(
                      width: 1.0,
                      color: app.colors.brandLineGrey,
                    ))),
                    child: ListView.builder(
                      controller: ScrollController(),
                      itemCount: provider.feed.length,
                      shrinkWrap: true,
                      itemBuilder: (context, index) {
                        ImageProvider? image = provider.tweetImageProviders[
                            provider.feed[index].get('id')];
                        return InkWell(
                          hoverColor: selectedFeedItem == index
                              ? app.colors.greyLight
                              : app.colors.white,
                          focusColor: selectedFeedItem == index
                              ? app.colors.greyLight
                              : app.colors.white,
                          onTap: () {
                            setState(() {
                              selectedFeedItem = index;
                            });
                            Item? feedItem = provider.feed[index];
                            setActiveFeedItem(feedItem: feedItem);
                          },
                          child: Container(
                            decoration: BoxDecoration(
                                border: Border(
                                    bottom: BorderSide(
                                        width: 1.0,
                                        color: app.colors.brandLineGrey))),
                            padding: EdgeInsets.all(20),
                            child: Column(
                              mainAxisSize: MainAxisSize.min,
                              children: [
                                ListTile(
                                  contentPadding: EdgeInsets.zero,
                                  minLeadingWidth: 15,
                                  minVerticalPadding: 0,
                                  dense: true,
                                  leading: CircleAvatar(
                                    radius: 17.5,
                                    backgroundImage: image,
                                    backgroundColor: app.colors.brandOrange,
                                    child: image == null &&
                                            provider
                                                    .getFeedAuthorName(index)
                                                    .length >
                                                1
                                        ? Text(
                                            provider
                                                .getFeedAuthorName(index)
                                                .substring(0, 1),
                                            style: AppStyles.buttonLabel
                                                .copyWith(
                                                    color: app.colors.white),
                                          )
                                        : null,
                                  ),
                                  title: Text(
                                    provider.getFeedAuthorName(index),
                                    style: AppStyles.bodyTiny.copyWith(
                                      fontSize: 13,
                                      color: app.colors.brandGreyText,
                                    ),
                                  ),
                                  subtitle: Text(
                                    '@' + provider.getFeedAuthorHandle(index),
                                    style: AppStyles.bodyTiny.copyWith(
                                      fontSize: 13,
                                      color: app.colors.brandGreyText,
                                    ),
                                  ),
                                  trailing:
                                      Text(provider.getFeedPostDate(index)),
                                ),
                                ListTile(
                                  contentPadding: EdgeInsets.zero,
                                  minLeadingWidth: 0,
                                  minVerticalPadding: 0,
                                  dense: true,
                                  title: Text(
                                    provider.feed[index].get('message') ?? '',
                                    style: AppStyles.bodyText1,
                                  ),
                                  trailing: app.icons.twitter(height: 20),
                                ),
                              ],
                            ),
                          ),
                        );
                      },
                    ),
                  ),
                ),
                if (ResponsiveHelper(context).isLargeScreen)
                  Expanded(child: SizedBox())
              ],
            ),
          );
        },
      ),
    );
  }

  void setActiveFeedItem({required feedItem}) async {
    // Reset active messages while waiting for query
    setState(() {
      activeFeedItem = feedItem;
    });
  }
}
