import 'package:flutter/material.dart';
import 'package:memri/configs/routes/route_navigator.dart';
import 'package:memri/constants/app_styles.dart';
import 'package:memri/core/models/item.dart';
import 'package:memri/providers/project_provider.dart';
import 'package:memri/utilities/helpers/app_helper.dart';
import 'package:memri/widgets/empty.dart';
import 'package:memri/widgets/scaffold/workspace_scaffold.dart';
import 'package:provider/provider.dart';

class ProjectsSummaryScreen extends StatefulWidget {
  const ProjectsSummaryScreen({Key? key, required this.id}) : super(key: key);
  final String id;

  @override
  State<ProjectsSummaryScreen> createState() => _ProjectsSummaryScreenState();
}

class _ProjectsSummaryScreenState extends State<ProjectsSummaryScreen> {
  @override
  void initState() {
    Provider.of<ProjectProvider>(context, listen: false)
        .setCurrentMemriProject(context, widget.id);
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    return WorkspaceScaffold(
      currentItem: NavigationItem.projects,
      backgroundColor: app.colors.greyBackGround,
      child: Consumer<ProjectProvider>(
        builder: (context, provider, _) => SingleChildScrollView(
          child: Container(
            width: MediaQuery.of(context).size.width,
            padding: EdgeInsets.symmetric(horizontal: 30),
            color: app.colors.greyBackGround,
            child: Column(
              crossAxisAlignment: CrossAxisAlignment.start,
              children: [
                Container(
                  color: app.colors.white,
                  padding: EdgeInsets.all(30),
                  child: Column(
                    crossAxisAlignment: CrossAxisAlignment.start,
                    children: [
                      Text(provider.currentProject?.get('name') ?? '',
                          style: AppStyles.headline1),
                      SizedBox(height: 32),
                      Column(
                        crossAxisAlignment: CrossAxisAlignment.start,
                        children: const [
                          Text('DATA SOURCE', style: AppStyles.smallCaps),
                          Text('Whatsapp', style: AppStyles.ul),
                        ],
                      ),
                      SizedBox(height: 30),
                      Row(
                        children: [
                          InkWell(
                            onTap: () => RouteNavigator.navigateTo(
                              route: Routes.projectsAppCreate,
                              context: context,
                              param: {'id': widget.id},
                            ),
                            child: Row(
                              children: [
                                app.icons.plus(color: app.colors.brandOrange),
                                SizedBox(width: 10),
                                Text(
                                  'Load and train a new ML model',
                                  style: AppStyles.tabList
                                      .copyWith(color: app.colors.brandOrange),
                                ),
                              ],
                            ),
                          ),
                          Spacer(),
                          InkWell(
                            onTap: () => provider.handleDeleteProject(context),
                            child: Row(
                              children: [
                                app.icons.delete(color: app.colors.brandOrange),
                                SizedBox(width: 10),
                                Text(
                                  'Delete project',
                                  style: AppStyles.tabList
                                      .copyWith(color: app.colors.brandOrange),
                                ),
                              ],
                            ),
                          ),
                        ],
                      ),
                    ],
                  ),
                ),
                SizedBox(height: 10),
                if (provider.currentDataset != null)
                  Container(
                    padding: EdgeInsets.all(30),
                    color: app.colors.white,
                    child: Column(
                      children: [
                        Row(
                          crossAxisAlignment: CrossAxisAlignment.start,
                          children: [
                            Expanded(
                              flex: 3,
                              child: Column(
                                crossAxisAlignment: CrossAxisAlignment.start,
                                children: [
                                  Text(
                                      provider.currentDataset?.get('name') ??
                                          '',
                                      style: AppStyles.headline2),
                                  Text(
                                      provider.currentProject?.get('name') ??
                                          '',
                                      style: AppStyles.ul.copyWith(
                                          color: app.colors.brandGreyText))
                                ],
                              ),
                            ),
                            Expanded(
                              flex: 3,
                              child: Column(
                                crossAxisAlignment: CrossAxisAlignment.start,
                                children: [
                                  Text('DATA TYPE',
                                      style: AppStyles.smallCaps.copyWith(
                                          color: app.colors.brandGreyText)),
                                  Text('Text', style: AppStyles.ul),
                                ],
                              ),
                            ),
                            Expanded(
                              flex: 3,
                              child: Column(
                                crossAxisAlignment: CrossAxisAlignment.start,
                                children: [
                                  Text('FEATURE VARIABLES',
                                      style: AppStyles.smallCaps.copyWith(
                                          color: app.colors.brandGreyText)),
                                  Text('date sent', style: AppStyles.ul),
                                  Text('content', style: AppStyles.ul),
                                ],
                              ),
                            ),
                            Expanded(child: Empty()),
                            Expanded(
                              flex: 2,
                              child: Column(
                                crossAxisAlignment: CrossAxisAlignment.start,
                                children: [
                                  Text('TEXT CLASSIFICATION',
                                      style: AppStyles.smallCaps.copyWith(
                                          color: app.colors.brandGreyText)),
                                  Text('binary', style: AppStyles.ul),
                                ],
                              ),
                            )
                          ],
                        ),
                        SizedBox(height: 64),
                        Row(
                            crossAxisAlignment: CrossAxisAlignment.start,
                            children: [
                              Expanded(flex: 3, child: Empty()),
                              Expanded(
                                flex: 3,
                                child: Column(
                                  crossAxisAlignment: CrossAxisAlignment.start,
                                  children: [
                                    Text('LABELLING PROGRESS',
                                        style: AppStyles.smallCaps.copyWith(
                                            color: app.colors.brandGreyText)),
                                    Text(
                                        '${provider.currentSummary.percentageLabeled + provider.currentSummary.percentageSkipped}%',
                                        style: AppStyles.ul),
                                  ],
                                ),
                              ),
                              Expanded(
                                flex: 3,
                                child: Column(
                                  crossAxisAlignment: CrossAxisAlignment.start,
                                  children: [
                                    Text('ITEMS',
                                        style: AppStyles.smallCaps.copyWith(
                                            color: app.colors.brandGreyText)),
                                    Row(
                                      children: [
                                        Text('Submitted',
                                            style: AppStyles.ul.copyWith(
                                                color:
                                                    app.colors.brandGreyText)),
                                        SizedBox(width: 8),
                                        Text(
                                            '${provider.currentSummary.numLabeled}',
                                            style: AppStyles.ul),
                                        SizedBox(width: 8),
                                        Text(
                                            '${provider.currentSummary.percentageLabeled}%',
                                            style: AppStyles.ul),
                                      ],
                                    ),
                                    Row(
                                      children: [
                                        Text('Skipped',
                                            style: AppStyles.ul.copyWith(
                                                color:
                                                    app.colors.brandGreyText)),
                                        SizedBox(width: 8),
                                        Text(
                                            '${provider.currentSummary.numSkipped}',
                                            style: AppStyles.ul),
                                        SizedBox(width: 8),
                                        Text(
                                            '${provider.currentSummary.percentageSkipped}%',
                                            style: AppStyles.ul),
                                      ],
                                    ),
                                    Row(
                                      children: [
                                        Text('Dataset',
                                            style: AppStyles.ul.copyWith(
                                                color:
                                                    app.colors.brandGreyText)),
                                        SizedBox(width: 8),
                                        Text('${provider.getDatasetSize()}',
                                            style: AppStyles.ul),
                                      ],
                                    ),
                                  ],
                                ),
                              ),
                              Expanded(child: Empty()),
                              Expanded(
                                flex: 2,
                                child: Column(
                                  crossAxisAlignment: CrossAxisAlignment.start,
                                  children: [
                                    Text('LABELS',
                                        style: AppStyles.smallCaps.copyWith(
                                            color: app.colors.brandGreyText)),
                                    for (Item labelOption
                                        in provider.getLabelOptions())
                                      Row(
                                        children: [
                                          Text(labelOption.get('name'),
                                              style: AppStyles.ul.copyWith(
                                                  color: app
                                                      .colors.brandGreyText)),
                                          SizedBox(width: 8),
                                          Text(
                                              "${provider.currentSummary.labelFrequencies[labelOption.get("name")] ?? 0}%",
                                              style: AppStyles.ul),
                                          SizedBox(width: 8),
                                          Text(
                                              "${provider.getLabelPercentage(provider.currentSummary.labelFrequencies[labelOption.get("name")])}%",
                                              style: AppStyles.ul),
                                        ],
                                      ),
                                  ],
                                ),
                              )
                            ]),
                        SizedBox(height: 30),
                        Row(
                          children: [
                            InkWell(
                              onTap: () => {
                                RouteNavigator.navigateTo(
                                    route: Routes.projectsLabelData,
                                    context: context,
                                    param: {'id': widget.id})
                              },
                              child: Row(
                                children: [
                                  app.icons.plus(color: app.colors.brandOrange),
                                  Text(
                                    'Resume labelling',
                                    style: AppStyles.tabList.copyWith(
                                        color: app.colors.brandOrange),
                                  ),
                                ],
                              ),
                            ),
                            Spacer(),
                            InkWell(
                              onTap: () =>
                                  provider.handleDeleteDataset(context),
                              child: Row(
                                children: [
                                  app.icons
                                      .delete(color: app.colors.brandOrange),
                                  Text(
                                    'Delete dataset',
                                    style: AppStyles.tabList.copyWith(
                                        color: app.colors.brandOrange),
                                  ),
                                ],
                              ),
                            ),
                          ],
                        )
                      ],
                    ),
                  ),
              ],
            ),
          ),
        ),
      ),
    );
  }
}
