import 'package:flutter/material.dart';
import 'package:memri/utilities/helpers/app_helper.dart';

class CustomLoadingIndicator extends StatefulWidget {
  const CustomLoadingIndicator(
      {Key? key, this.size = 20, this.speed = 1, this.color})
      : super(key: key);

  final double size;
  final double? speed;
  final Color? color;

  @override
  _CustomLoadingIndicatorState createState() => _CustomLoadingIndicatorState();
}

class _CustomLoadingIndicatorState extends State<CustomLoadingIndicator>
    with TickerProviderStateMixin {
  late AnimationController rotateController;
  late Animation<double> rotateAnimation;

  late Future _init;

  @override
  void initState() {
    rotateController = AnimationController(
      duration: const Duration(seconds: 1),
      reverseDuration: const Duration(seconds: 1),
      vsync: this,
    );

    rotateAnimation =
        CurvedAnimation(parent: rotateController, curve: Curves.linear);
    _init = init();
    super.initState();
  }

  init() async {
    rotateController.repeat(
      min: 0,
      max: 1,
      period: Duration(milliseconds: 1000 ~/ (widget.speed ?? 1)),
    );
  }

  @override
  void didUpdateWidget(oldWidget) {
    super.didUpdateWidget(oldWidget);
    _init = init();
  }

  @override
  void dispose() {
    rotateController.dispose();
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    return FutureBuilder(
      future: _init,
      builder: (_, __) => RotationTransition(
        turns: rotateAnimation,
        child: app.icons.loader(
          color: widget.color ?? Color(0xFFFE570F),
          width: widget.size,
          height: widget.size,
        ),
      ),
    );
  }
}
