import 'package:flutter/material.dart';
import 'package:memri/constants/app_styles.dart';
import 'package:memri/core/models/item.dart';
import 'package:memri/core/models/running_plugin.dart';
import 'package:memri/providers/data_app_provider.dart';
import 'package:memri/utilities/helpers/responsive_helper.dart';
import 'package:memri/widgets/data_app/data_app_list.dart';
import 'package:memri/widgets/loading_indicator.dart';
import 'package:provider/provider.dart';

class DataApp extends StatefulWidget {
  const DataApp({Key? key, required this.runningPlugin, required this.pluginId})
      : super(key: key);

  final RunningPlugin? runningPlugin;
  final String pluginId;

  @override
  State<DataApp> createState() => _DataAppState();
}

class _DataAppState extends State<DataApp> {
  late final _dataAppProvider =
      Provider.of<DataAppProvider>(context, listen: false);
  List<Item> appContent = [];
  bool contentHasLoaded = false;

  @override
  void initState() {
    loadAppContent();
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    if (!contentHasLoaded) {
      return LoadingIndicator(message: 'Loading your App...!');
    }

    return SingleChildScrollView(child:
        Consumer<DataAppProvider>(builder: (context, dataAppProvider, _) {
      return Container(
        padding: EdgeInsets.symmetric(vertical: 8),
        child: Row(
          children: [
            Expanded(
              flex: 2,
              child: Padding(
                padding: EdgeInsets.symmetric(
                  horizontal: 30,
                  vertical:
                      20 + (!ResponsiveHelper(context).isSmallScreen ? 20 : 0),
                ),
                child: Column(
                  crossAxisAlignment: CrossAxisAlignment.start,
                  children: [
                    Text(
                      _dataAppProvider.currentPlugin?.get('name') ??
                          'Untitled App',
                      style: AppStyles.headline1,
                    ),
                    if (widget.runningPlugin?.plugin.get('pluginDescription') !=
                        null)
                      Padding(
                        padding: const EdgeInsets.only(top: 10),
                        child: Text(
                          widget.runningPlugin?.plugin.get('pluginDescription'),
                          style: AppStyles.bodyText1,
                        ),
                      ),
                    SizedBox(height: 50),
                    DataAppList(contents: _dataAppProvider.currentDataAppItems),
                  ],
                ),
              ),
            ),
            if (!ResponsiveHelper(context).isSmallScreen)
              Expanded(flex: 1, child: Container())
          ],
        ),
      );
    }));
  }

  loadAppContent() async {
    contentHasLoaded = false;

    _dataAppProvider.currentDataType =
        await _dataAppProvider.getDataTypeForPlugin(widget.pluginId);
    _dataAppProvider.currentDataAppItems = await _dataAppProvider
        .loadAppContent(widget.pluginId, _dataAppProvider.currentDataType!,
            onlyWithPredictions: false);

    contentHasLoaded = true;
    setState(() {});
  }
}
