import 'package:flutter/material.dart';
import 'package:memri/constants/app_colors.dart';
import 'package:memri/constants/app_styles.dart';
import 'package:memri/utilities/extensions/date_time.dart';
import 'package:memri/utilities/helpers/app_helper.dart';
import 'package:memri/utilities/helpers/time_helper.dart';

import '../../core/models/item.dart';

class DataAppRow extends StatelessWidget {
  const DataAppRow({
    Key? key,
    required this.contentItem,
    required this.label,
    required this.labelColor,
  }) : super(key: key);

  final Item contentItem;
  final String? label;
  final Color labelColor;

  @override
  Widget build(BuildContext context) {
    return contentItem.type == 'Message'
        ? buildWhatsappContent(context)
        : buildTwitterContent(context);
  }

  Widget buildWhatsappContent(BuildContext context) {
    String content = contentItem.get('content') ?? '[NO CONTENT]';
    String date = formatTimestamp(contentItem.get('dateSent')).toString();
    return ListTile(
        dense: true,
        minVerticalPadding: 0,
        contentPadding: EdgeInsets.zero,
        title: Text(
          content,
          style: AppStyles.bodyText1,
          maxLines: 5,
        ),
        subtitle: Text(date,
            style:
                AppStyles.bodyTiny.copyWith(color: app.colors.brandGreyText)),
        trailing: (label != null)
            ? Chip(
                label: Text(
                  label!,
                  style: AppStyles.bodyText1.copyWith(color: app.colors.white),
                ),
                backgroundColor: labelColor,
                padding: EdgeInsets.symmetric(horizontal: 10, vertical: 5),
              )
            : null);
  }

  Widget buildTwitterContent(BuildContext context) {
    String content = contentItem.get('message') ?? '[NO CONTENT]';
    int date = contentItem.get('postDate');
    // ignore: prefer_adjacent_string_concatenation
    // TODO: twitter authors here (need to be implemented in mock items)
    String header = '';
    // String header = contentItem.edgeItem('author')?.get('displayName') + '@' + contentItem.edgeItem('author')?.get('handle');

    return Column(
      crossAxisAlignment: CrossAxisAlignment.start,
      children: [
        Text(
          header,
          style: AppStyles.bodyText1.copyWith(color: AppColors().brandGreyText),
        ),
        ListTile(
          dense: true,
          minVerticalPadding: 8,
          contentPadding: EdgeInsets.zero,
          isThreeLine: true,
          title: Text(
            content,
            style: AppStyles.bodyText1,
            maxLines: 5,
          ),
          subtitle: Text(DateTimeHelper().getDateTimeString(date),
              style:
                  AppStyles.bodyTiny.copyWith(color: app.colors.brandGreyText)),
          trailing: (label != null)
              ? Chip(
                  label: Text(
                    label!,
                    style:
                        AppStyles.bodyText1.copyWith(color: app.colors.white),
                  ),
                  backgroundColor: labelColor,
                  padding: EdgeInsets.symmetric(horizontal: 10, vertical: 5),
                )
              : null,
        ),
      ],
    );
  }

  String formatTimestamp(int? timestamp) {
    if (timestamp != null) {
      return DateTime.fromMillisecondsSinceEpoch(timestamp)
          .formatted(dateFormat: 'yyyy/MM/dd')
          .toString();
    }
    return '';
  }
}
