import 'package:flutter/material.dart';
import 'package:memri/constants/app_styles.dart';
import 'package:memri/core/models/running_plugin.dart';
import 'package:memri/providers/data_app_provider.dart';
import 'package:memri/providers/navigation_provider.dart';
import 'package:memri/utilities/helpers/app_helper.dart';
import 'package:memri/utilities/helpers/responsive_helper.dart';
import 'package:memri/widgets/simple_text_editor.dart';
import 'package:provider/provider.dart';

class DataAppSettings extends StatefulWidget {
  const DataAppSettings({Key? key, required this.runningPlugin})
      : super(key: key);

  final RunningPlugin? runningPlugin;

  @override
  State<DataAppSettings> createState() => _DataAppSettingsState();
}

class _DataAppSettingsState extends State<DataAppSettings> {
  late final _dataAppProvider =
      Provider.of<DataAppProvider>(context, listen: false);
  late final _navProvider =
      Provider.of<NavigationProvider>(context, listen: false);
  final _appNameController = TextEditingController();
  final _appDescriptionController = TextEditingController();

  @override
  void initState() {
    resetSettingsControllers();
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    return Row(
      children: [
        Expanded(
          flex: 2,
          child: Padding(
            padding: const EdgeInsets.symmetric(horizontal: 30),
            child: Column(
              crossAxisAlignment: CrossAxisAlignment.start,
              children: [
                SizedBox(height: 20),
                if (!ResponsiveHelper(context).isSmallScreen)
                  SizedBox(height: 20),
                Text(
                  'App Settings',
                  style: AppStyles.headline3.copyWith(
                    fontSize: 15,
                    fontWeight: FontWeight.w700,
                  ),
                ),
                SizedBox(height: 10),
                Text(
                  'Please provide a name for your App',
                  style: AppStyles.bodyText1,
                ),
                SizedBox(height: 20),
                SimpleTextEditor(
                  controller: _appNameController,
                  title: 'APP NAME',
                  hintText: 'Choose a name for your app',
                  textColor: app.colors.brandBlack,
                ),
                SizedBox(height: 30),
                SimpleTextEditor(
                  controller: _appDescriptionController,
                  title: 'APP Description',
                  hintText: 'Write a description for your app',
                  textColor: app.colors.brandBlack,
                ),
                SizedBox(height: 40),
                Row(
                  children: [
                    TextButton(
                      onPressed: () {
                        _dataAppProvider.updateProjectSettings(
                            widget.runningPlugin,
                            _appNameController.text,
                            _appDescriptionController.text);
                        _navProvider.setSelectedTabIndex(0);
                        _dataAppProvider.setDataAppState(AppState.showApp);
                      },
                      style: primaryButtonStyle,
                      child: SizedBox(
                        height: 36,
                        child: Row(
                          mainAxisSize: MainAxisSize.min,
                          children: const [
                            Text('Save', style: AppStyles.buttonLabel)
                          ],
                        ),
                      ),
                    ),
                    SizedBox(width: 10),
                    TextButton(
                      style: secondaryButtonStyle,
                      onPressed: () {
                        resetSettingsControllers();
                        _navProvider.setSelectedTabIndex(0);
                        _dataAppProvider.setDataAppState(AppState.showApp);
                      },
                      child: SizedBox(
                        height: 36,
                        child: Padding(
                          padding: const EdgeInsets.symmetric(horizontal: 10),
                          child: Row(
                            mainAxisSize: MainAxisSize.min,
                            children: [
                              Text(
                                'Cancel',
                                style: AppStyles.buttonLabel
                                    .copyWith(color: app.colors.brandOrange),
                              )
                            ],
                          ),
                        ),
                      ),
                    ),
                  ],
                ),
                SizedBox(height: 20),
                if (!ResponsiveHelper(context).isSmallScreen)
                  SizedBox(height: 20),
              ],
            ),
          ),
        ),
        Expanded(flex: 1, child: Container())
      ],
    );
  }

  resetSettingsControllers() {
    _appNameController.text = widget.runningPlugin?.plugin.get('name') ?? '';
    _appDescriptionController.text =
        widget.runningPlugin?.plugin.get('pluginDescription') ?? '';
  }
}
