import 'package:flutter/material.dart';
import 'package:flutter_svg/flutter_svg.dart';
import 'package:memri/constants/app_styles.dart';
import 'package:memri/providers/oauth_provider.dart';
import 'package:memri/utilities/helpers/app_helper.dart';
import 'package:memri/widgets/importer/importer_info_line.dart';
import 'package:memri/widgets/screen_error.dart';
import 'package:provider/provider.dart';

class ImporterConnectWhatsapp extends StatefulWidget {
  const ImporterConnectWhatsapp({Key? key}) : super(key: key);

  @override
  State<ImporterConnectWhatsapp> createState() =>
      _ImporterConnectWhatsappState();
}

class _ImporterConnectWhatsappState extends State<ImporterConnectWhatsapp> {
  @override
  Widget build(BuildContext context) {
    return Consumer<OAuthProvider>(builder: (context, provider, _) {
      return provider.whatsappStatus == 'error'
          ? ScreenError(
              title: 'Whatsapp importer failed to load your data.',
              message:
                  'Whatsapp importer failed to load your data. Please try again.',
            )
          : Column(
              mainAxisAlignment: MainAxisAlignment.start,
              crossAxisAlignment: CrossAxisAlignment.start,
              children: [
                Text('On your phone', style: AppStyles.headline1),
                SizedBox(height: 22),
                ImporterInfoLine(
                    contents: const ['Open', ' Whatsapp'],
                    weights: const [FontWeight.normal, FontWeight.bold]),
                SizedBox(height: 12),
                ImporterInfoLine(
                  contents: const [
                    'Tap ',
                    'settings ',
                    'and select ',
                    'Linked devices'
                  ],
                  weights: const [
                    FontWeight.normal,
                    FontWeight.bold,
                    FontWeight.normal,
                    FontWeight.bold
                  ],
                ),
                SizedBox(height: 12),
                ImporterInfoLine(
                  contents: const ['Tap', ' Link a device'],
                  weights: const [FontWeight.normal, FontWeight.bold],
                ),
                SizedBox(height: 12),
                ImporterInfoLine(
                  contents: const [
                    'Point your phone to the QR code on the screen of your computer to',
                    ' capture the code'
                  ],
                  weights: const [FontWeight.normal, FontWeight.bold],
                ),
                SizedBox(height: 20),
                if (provider.whatsappStatus == 'authenticated' ||
                    provider.whatsappStatus == 'daemon')
                  Padding(
                    padding: const EdgeInsets.only(top: 50),
                    child: Text(
                      'Signing in...',
                      style: TextStyle(
                          color: app.colors.brandOrange, fontSize: 14),
                    ),
                  )
                else if (provider.whatsappQrSvg != null)
                  SvgPicture.memory(
                    provider.whatsappQrSvg!,
                    height: 350,
                    width: 350,
                  )
                else if (provider.whatsappStatus == 'error')
                  Container(
                    height: 350,
                    width: 350,
                    color: Color(0xffF6F6F6),
                    padding: EdgeInsets.all(30),
                    child: Center(child: Text('Something went wrong')),
                  )
                else
                  Container(
                    height: 350,
                    width: 350,
                    color: Color(0xffF6F6F6),
                    padding: EdgeInsets.all(30),
                    child: Center(
                        child: Text(
                      'Please wait for your QR code to be generated. This make take a few moments.',
                      style: TextStyle(
                        fontSize: 14,
                        color: app.colors.brandGreyText,
                      ),
                    )),
                  ),
                SizedBox(height: 20),
              ],
            );
    });
  }
}
