import 'package:flutter/material.dart';
import 'package:memri/constants/app_styles.dart';
import 'package:memri/utilities/helpers/app_helper.dart';

class ImporterTile extends StatelessWidget {
  const ImporterTile({
    Key? key,
    required this.title,
    required this.onTap,
    this.status,
    this.featureVariables,
    this.description,
    this.selectable = true,
    this.selected = false,
    this.active = false,
    this.statusColor,
  }) : super(key: key);

  final String title;
  final int? featureVariables;
  final String? description;
  final String? status;
  final VoidCallback? onTap;
  final bool selectable;
  final bool selected;
  final bool active;
  final Color? statusColor;

  @override
  Widget build(BuildContext context) {
    return InkWell(
      onTap: onTap,
      child: Container(
        width: 205,
        height: 95,
        decoration: selected
            ? BoxDecoration(
                border: Border.all(color: app.colors.brandOrange),
                color: app.colors.backgroundOrange)
            : BoxDecoration(
                color: active && selectable
                    ? app.colors.greyBackGround
                    : app.colors.white,
                border: Border.all(color: app.colors.brandLineGrey, width: 1),
              ),
        child: Stack(
          children: [
            Positioned(
              top: 10,
              right: 10,
              left: 10,
              child: Text(
                title,
                style: AppStyles.headline3.copyWith(
                    fontSize: 15,
                    fontWeight: FontWeight.bold,
                    color: selected
                        ? app.colors.brandOrange
                        : active || !selectable
                            ? app.colors.brandBlack
                            : app.colors.brandGreyText),
              ),
            ),
            Positioned(
              bottom: 10,
              right: 10,
              left: 10,
              child: Column(
                crossAxisAlignment: CrossAxisAlignment.start,
                children: [
                  if (featureVariables != null)
                    Text(
                      '$featureVariables feature variables',
                      style: AppStyles.bodyTiny
                          .copyWith(color: app.colors.brandGrey),
                    ),
                  if (description != null)
                    Text(
                      description!,
                      style: AppStyles.bodyTiny
                          .copyWith(color: app.colors.brandGrey),
                    ),
                  if (status != null)
                    Text(
                      status!,
                      style: AppStyles.bodyTiny.copyWith(
                        fontWeight: FontWeight.w700,
                        color: selected
                            ? app.colors.brandOrange
                            : statusColor ?? app.colors.brandOrange,
                      ),
                    ),
                ],
              ),
            ),
          ],
        ),
      ),
    );
  }
}
