import 'package:flutter/material.dart';
import 'package:memri/constants/app_styles.dart';
import 'package:memri/localization/generated/l10n.dart';
import 'package:memri/providers/app_provider.dart';
import 'package:memri/providers/navigation_provider.dart';
import 'package:memri/providers/pod_provider.dart';
import 'package:memri/utilities/helpers/app_helper.dart';
import 'package:provider/provider.dart';

class DrawerMenu extends StatefulWidget {
  const DrawerMenu({Key? key}) : super(key: key);

  @override
  State<DrawerMenu> createState() => _DrawerMenuState();
}

class _DrawerMenuState extends State<DrawerMenu> {
  late final _navigationProvider =
      Provider.of<NavigationProvider>(context, listen: false);
  late final _appProvider = Provider.of<AppProvider>(context, listen: false);
  late final _podProvider = Provider.of<PodProvider>(context, listen: false);

  @override
  Widget build(BuildContext context) {
    return Container(
      width: MediaQuery.of(context).size.width * 6 / 11,
      height: MediaQuery.of(context).size.height,
      color: app.colors.brandViolet,
      padding: EdgeInsets.all(24),
      child: Stack(
        children: [
          SingleChildScrollView(
            controller: ScrollController(),
            child: Column(
              crossAxisAlignment: CrossAxisAlignment.start,
              children: [
                Text(
                  S.current.community_and_support,
                  style: AppStyles.bodyBold.copyWith(color: Colors.white),
                ),
                Divider(color: app.colors.brandWhite),
                ListTile(
                  contentPadding: EdgeInsets.zero,
                  minLeadingWidth: 0,
                  onTap: _navigationProvider.openDiscordLink,
                  title: Text(
                    S.current.chat_on_discord,
                    style: AppStyles.bodyText1.copyWith(color: Colors.white),
                  ),
                ),
                ListTile(
                  contentPadding: EdgeInsets.zero,
                  minLeadingWidth: 0,
                  onTap: _navigationProvider.openDocumentationLink,
                  title: Text(
                    S.current.documentation,
                    style: AppStyles.bodyText1.copyWith(color: Colors.white),
                  ),
                ),
                ListTile(
                  contentPadding: EdgeInsets.zero,
                  minLeadingWidth: 0,
                  onTap: _navigationProvider.openGitlabLink,
                  title: Text(
                    S.current.repositories,
                    style: AppStyles.bodyText1.copyWith(color: Colors.white),
                  ),
                ),
                SizedBox(height: 30),
                Text(
                  S.current.legal,
                  style: AppStyles.bodyBold.copyWith(color: Colors.white),
                ),
                Divider(color: app.colors.brandWhite),
                ListTile(
                  contentPadding: EdgeInsets.zero,
                  minLeadingWidth: 0,
                  onTap: _navigationProvider.openPrivacyLink,
                  title: Text(
                    S.current.privacy_and_security,
                    style: AppStyles.bodyText1.copyWith(color: Colors.white),
                  ),
                ),
                ListTile(
                  contentPadding: EdgeInsets.zero,
                  minLeadingWidth: 0,
                  onTap: _navigationProvider.openContactLink,
                  title: Text(
                    S.current.contact_us,
                    style: AppStyles.bodyText1.copyWith(color: Colors.white),
                  ),
                ),
                SizedBox(height: 30),
                Text(
                  S.current.account,
                  style: AppStyles.bodyBold.copyWith(color: Colors.white),
                ),
                Divider(color: app.colors.brandWhite),
                ListTile(
                  contentPadding: EdgeInsets.zero,
                  minLeadingWidth: 0,
                  onTap: () => _navigationProvider.openPodKeys(context),
                  title: Text(
                    S.current.your_pod_keys,
                    style: AppStyles.bodyText1.copyWith(color: Colors.white),
                  ),
                  leading: app.icons.key(),
                ),
                ListTile(
                  contentPadding: EdgeInsets.zero,
                  minLeadingWidth: 0,
                  onTap: () => _podProvider.signOut(context),
                  title: Text(
                    S.current.sign_out,
                    style: AppStyles.bodyText1.copyWith(color: Colors.white),
                  ),
                  leading: app.icons.logOut(),
                ),
              ],
            ),
          ),
          Positioned(
            bottom: 0,
            right: 0,
            left: 0,
            child: Container(
              color: app.colors.brandViolet,
              padding: EdgeInsets.symmetric(vertical: 4),
              child: Row(
                children: [
                  Column(
                    crossAxisAlignment: CrossAxisAlignment.start,
                    children: [
                      Text(
                        '${S.current.app}: ${_appProvider.appVersion}',
                        style: AppStyles.bodyText1.copyWith(
                            color: app.colors.white.withOpacity(0.25)),
                      ),
                      SizedBox(height: 4),
                      Text(
                        '${S.current.pod}: ${_appProvider.podVersion}',
                        style: AppStyles.bodyText1.copyWith(
                            color: app.colors.white.withOpacity(0.25)),
                      ),
                    ],
                  ),
                  Spacer(),
                  app.images.logo(
                    height: 32,
                    color: app.colors.white,
                  ),
                ],
              ),
            ),
          ),
        ],
      ),
    );
  }
}
