import 'package:flutter/material.dart';
import 'package:memri/configs/routes/route_navigator.dart';
import 'package:memri/constants/app_styles.dart';
import 'package:memri/localization/generated/l10n.dart';
import 'package:memri/providers/app_provider.dart';
import 'package:memri/providers/navigation_provider.dart';
import 'package:memri/providers/pod_provider.dart';
import 'package:memri/utilities/helpers/app_helper.dart';
import 'package:provider/provider.dart';

class PaneMenu extends StatefulWidget {
  const PaneMenu({Key? key}) : super(key: key);

  @override
  State<PaneMenu> createState() => _PaneMenuState();
}

class _PaneMenuState extends State<PaneMenu> {
  late final _navigationProvider =
      Provider.of<NavigationProvider>(context, listen: false);
  late final _appProvider = Provider.of<AppProvider>(context, listen: false);
  late final _podProvider = Provider.of<PodProvider>(context, listen: false);

  @override
  Widget build(BuildContext context) {
    return Container(
      height: 370,
      width: MediaQuery.of(context).size.width,
      color: app.colors.brandViolet,
      child: Padding(
        padding: const EdgeInsets.all(30),
        child: Column(
          crossAxisAlignment: CrossAxisAlignment.start,
          children: [
            Row(
              children: [
                TextButton(
                  onPressed: _navigationProvider.closeMenu,
                  child: app.icons.close(),
                ),
                Spacer(),
                InkWell(
                  onTap: () => RouteNavigator.navigateTo(
                      context: context,
                      route: Routes.workspace,
                      clearStack: true),
                  child: app.images.logo(color: app.colors.white),
                )
              ],
            ),
            SizedBox(height: 64),
            Expanded(child: _buildMenu()),
          ],
        ),
      ),
    );
  }

  Widget _buildMenu() {
    var width = MediaQuery.of(context).size.width;

    return Row(
      children: [
        if (width > 190)
          Column(
            crossAxisAlignment: CrossAxisAlignment.start,
            children: [
              Text(
                S.current.account,
                style: AppStyles.bodyBold.copyWith(color: Colors.white),
              ),
              SizedBox(height: 10),
              InkWell(
                onTap: () => _navigationProvider.openPodKeys(context),
                child: Row(
                  children: [
                    app.icons.key(),
                    SizedBox(width: 10),
                    Text(
                      S.current.your_pod_keys,
                      style: AppStyles.bodyText1.copyWith(color: Colors.white),
                    )
                  ],
                ),
              ),
              SizedBox(height: 10),
              InkWell(
                onTap: () {
                  _navigationProvider.closeMenu();
                  _podProvider.signOut(context);
                },
                child: Row(
                  children: [
                    app.icons.logOut(),
                    SizedBox(width: 10),
                    Text(
                      S.current.sign_out,
                      style: AppStyles.bodyText1.copyWith(color: Colors.white),
                    )
                  ],
                ),
              )
            ],
          ),
        if (width > 525) SizedBox(width: 180),
        if (width > 525)
          Column(
            crossAxisAlignment: CrossAxisAlignment.start,
            children: [
              Text(
                S.current.community_and_support,
                style: AppStyles.bodyBold.copyWith(color: Colors.white),
              ),
              SizedBox(height: 10),
              InkWell(
                onTap: _navigationProvider.openDiscordLink,
                child: Text(
                  S.current.chat_on_discord,
                  style: AppStyles.bodyText1.copyWith(color: Colors.white),
                ),
              ),
              SizedBox(height: 10),
              InkWell(
                onTap: _navigationProvider.openDocumentationLink,
                child: Text(
                  S.current.documentation,
                  style: AppStyles.bodyText1.copyWith(color: Colors.white),
                ),
              ),
              SizedBox(height: 10),
              InkWell(
                onTap: _navigationProvider.openGitlabLink,
                child: Text(
                  S.current.repositories,
                  style: AppStyles.bodyText1.copyWith(color: Colors.white),
                ),
              ),
            ],
          ),
        if (width > 865) SizedBox(width: 180),
        if (width > 865)
          Column(
            crossAxisAlignment: CrossAxisAlignment.start,
            children: [
              Text(
                S.current.legal,
                style: AppStyles.bodyBold.copyWith(color: Colors.white),
              ),
              SizedBox(height: 10),
              InkWell(
                onTap: _navigationProvider.openPrivacyLink,
                child: Text(
                  S.current.privacy_and_security,
                  style: AppStyles.bodyText1.copyWith(color: Colors.white),
                ),
              ),
              SizedBox(height: 10),
              InkWell(
                onTap: _navigationProvider.openContactLink,
                child: Text(
                  S.current.contact_us,
                  style: AppStyles.bodyText1.copyWith(color: Colors.white),
                ),
              ),
            ],
          ),
        if (width > 1140) SizedBox(width: 180),
        if (width > 1140)
          Column(
            crossAxisAlignment: CrossAxisAlignment.start,
            children: [
              Text(
                S.current.version,
                style: AppStyles.bodyBold
                    .copyWith(color: app.colors.white.withOpacity(0.25)),
              ),
              SizedBox(height: 10),
              Text(
                '${S.current.app}: ${_appProvider.appVersion}',
                style: AppStyles.bodyText1
                    .copyWith(color: app.colors.white.withOpacity(0.25)),
              ),
              SizedBox(height: 10),
              Text(
                '${S.current.pod}: ${_appProvider.podVersion}',
                style: AppStyles.bodyText1
                    .copyWith(color: app.colors.white.withOpacity(0.25)),
              ),
            ],
          ),
      ],
    );
  }
}
