import 'package:flutter/material.dart';
import 'package:memri/constants/app_styles.dart';
import 'package:memri/utilities/helpers/app_helper.dart';
import 'package:memri/utilities/helpers/responsive_helper.dart';
import 'package:scrollable_positioned_list/scrollable_positioned_list.dart';

class ProjectProgressBar extends StatelessWidget {
  ProjectProgressBar(
      {Key? key, required this.child, required this.currentStep, this.summary})
      : super(key: key);

  final Widget child;
  final Widget? summary;
  final int currentStep;

  final List<String> _steps = [
    'Set up project',
    'Label data',
    'Load and train a ML model',
    'Preview app',
    'Edit UI',
  ];

  @override
  Widget build(BuildContext context) {
    return Container(
      width: MediaQuery.of(context).size.width,
      height: MediaQuery.of(context).size.height,
      color: app.colors.greyBackGround,
      child: ResponsiveHelper(context).isSmallScreen
          ? _buildMobileBody(context)
          : _buildDesktopBody(context),
    );
  }

  Widget _buildDesktopBody(BuildContext context) {
    return Row(
      crossAxisAlignment: CrossAxisAlignment.start,
      children: [
        Expanded(
          flex: ResponsiveHelper(context).isMediumScreen ? 2 : 1,
          child: _buildDesktopStepsSideBar(context),
        ),
        SizedBox(width: 2),
        Expanded(
          flex: ResponsiveHelper(context).isMediumScreen ? 5 : 3,
          child: child,
        ),
      ],
    );
  }

  Widget _buildMobileBody(BuildContext context) {
    return SingleChildScrollView(
      child: Column(
        children: [
          _buildMobileStepsSideBar(context),
          SizedBox(height: 2),
          child,
        ],
      ),
    );
  }

  _buildDesktopStepsSideBar(BuildContext context) {
    return Container(
      width: MediaQuery.of(context).size.width,
      height: MediaQuery.of(context).size.height,
      color: app.colors.white,
      child: Padding(
        padding: const EdgeInsets.only(top: 30),
        child: ScrollablePositionedList.builder(
          shrinkWrap: true,
          itemCount: _steps.length,
          itemBuilder: (context, index) {
            var color = app.colors.brandBlack;
            if (index == currentStep) {
              color = app.colors.primary;
            } else if (index > currentStep) {
              color = app.colors.brandGreyText;
            }
            return Column(
              children: [
                ListTile(
                  minLeadingWidth: 17,
                  contentPadding:
                      EdgeInsets.symmetric(vertical: 10, horizontal: 30),
                  title: Text(
                    _steps.elementAt(index),
                    style:
                        AppStyles.bodyBold.copyWith(fontSize: 15, color: color),
                  ),
                  leading: Container(
                    width: 32,
                    height: 32,
                    decoration: BoxDecoration(
                      shape: BoxShape.circle,
                      color: color,
                    ),
                    child: Center(
                      child: Text(
                        '${index + 1}',
                        style: AppStyles.smallCaps
                            .copyWith(color: app.colors.white),
                      ),
                    ),
                  ),
                ),
                if (summary != null && index == currentStep)
                  Padding(
                    padding: EdgeInsets.symmetric(
                      horizontal:
                          ResponsiveHelper(context).isLargeScreen ? 75 : 40,
                      vertical: 20,
                    ),
                    child: summary!,
                  ),
              ],
            );
          },
        ),
      ),
    );
  }

  _buildMobileStepsSideBar(BuildContext context) {
    return Container(
      width: MediaQuery.of(context).size.width,
      height: 80,
      color: app.colors.white,
      child: Column(
        children: [
          SizedBox(height: 10),
          Flexible(
            child: ScrollablePositionedList.builder(
              scrollDirection: Axis.horizontal,
              shrinkWrap: true,
              initialScrollIndex: currentStep,
              itemCount: _steps.length,
              itemBuilder: (context, index) {
                var color = app.colors.brandBlack;
                if (index == currentStep) {
                  color = app.colors.primary;
                } else if (index > currentStep) {
                  color = app.colors.brandGreyText;
                }
                return Container(
                  padding: const EdgeInsets.symmetric(vertical: 15),
                  child: Row(
                    mainAxisSize: MainAxisSize.min,
                    children: [
                      if (index == 0) SizedBox(width: 30),
                      Container(
                        width: 32,
                        height: 32,
                        decoration: BoxDecoration(
                          shape: BoxShape.circle,
                          color: color,
                        ),
                        child: Center(
                          child: Text(
                            '${index + 1}',
                            style: AppStyles.smallCaps
                                .copyWith(color: app.colors.white),
                          ),
                        ),
                      ),
                      SizedBox(width: 17),
                      Text(
                        _steps.elementAt(index),
                        style: AppStyles.bodyBold
                            .copyWith(fontSize: 15, color: color),
                      ),
                      SizedBox(width: 30),
                    ],
                  ),
                );
              },
            ),
          ),
        ],
      ),
    );
  }
}
