import 'package:flutter/material.dart';
import 'package:memri/providers/navigation_provider.dart';
import 'package:memri/utilities/helpers/responsive_helper.dart';
import 'package:memri/widgets/navigation/bottom_bar.dart';
import 'package:memri/widgets/navigation/menu/drawer_menu.dart';
import 'package:memri/widgets/navigation/top_bar.dart';
import 'package:memri/widgets/scaffold/base_scaffold.dart';
import 'package:provider/provider.dart';

enum NavigationItem { workspace, data, projects, apps }

class WorkspaceScaffold extends StatelessWidget {
  WorkspaceScaffold({
    Key? key,
    required this.currentItem,
    required this.child,
    this.backgroundColor,
    this.tabs,
  }) : super(key: key);

  final Widget child;
  final NavigationItem currentItem;
  final GlobalKey<ScaffoldState> _scaffoldKey = GlobalKey<ScaffoldState>();
  final Color? backgroundColor;
  final List<TabItem>? tabs;

  @override
  Widget build(BuildContext context) {
    return Consumer<NavigationProvider>(
      builder: (BuildContext context, provider, _) => BaseScaffold(
        scaffoldKey: _scaffoldKey,
        topBar: TopBar(
          currentItem: currentItem,
          scaffoldKey: _scaffoldKey,
          height: ResponsiveHelper(context).isSmallScreen
              ? kToolbarHeight
              : provider.isMenuVisible
                  ? 370
                  : 190,
          tabs: tabs,
        ),
        bottomBar: ResponsiveHelper(context).isSmallScreen
            ? BottomBar(currentItem: currentItem)
            : null,
        drawer: ResponsiveHelper(context).isSmallScreen ? DrawerMenu() : null,
        body: child,
        backgroundColor: backgroundColor,
      ),
    );
  }
}
